<?php

namespace Drupal\development_assistant\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\browser_development\Processing\FormsStorage;

/**
 * Settings page for editor variables.
 *
 * Drupal\development_assistant\Form.
 */
class Settings extends FormBase {

  /**
   * Forms unique identifier.
   *
   * @return string
   *   Returns form unique identifier string
   */
  public function getFormId() {
    return 'development_assistant_settings';
  }

  /**
   * Build form array.
   *
   * @param array $form
   *   Adds form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Gets form state including input values.
   *
   * @return array
   *   Returns form array elements .
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $uri = 1;
    if (!empty(FormsStorage::getStorage('development_assistant_settings')['browser_development_settings'])) {
      $uri =FormsStorage::getStorage('development_assistant_settings')['browser_development_settings']['uri'];  
    }
    else {
      $uri = $form_state->getValue('api_uri');
    }

    $form['api_uri'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Api Url'),
      '#default_value' => $uri,
    ];


    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * Validation method.
   *
   * @param array $form
   *   Array form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Gets form state including input values.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * Form submit method.
   *
   * @param array $form
   *   Array form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Gets form state including input values.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    FormsStorage::setStorage('development_assistant_settings', [
      'uri' => $form_state->getValue('api_uri'),
    ]);

    $uriStorage = FormsStorage::getStorage('development_assistant_settings')['development_assistant_settings'];
    $this->messenger()->addMessage($this->t('API information @api.', ['@api' => print_r($uriStorage, TRUE)]));
  }

}
